habitat.utils.checksums
=======================

.. automodule:: habitat.utils.checksums

   
   
   .. rubric:: Functions

   .. autosummary::
   
      crc16_ccitt
      fletcher_16
      op_xor
      xor
   
   

   
   
   

   
   
   